import { github } from "@/server/auth/oauth";
import { generateState } from "arctic";
import { cookies } from "next/headers";

export const dynamic = "force-dynamic";

export async function GET(): Promise<Response> {
	const state = generateState();
	
	// Explizit die redirect_uri übergeben, um Konsistenz zu gewährleisten
	const callbackUrl = new URL("/auth/login/callback", process.env.NEXT_PUBLIC_FRONTEND_URL || "http://localhost:3000").toString();
	
	const url = await github.createAuthorizationURL(state, {
		scopes: ["user"],
		redirectURI: callbackUrl,
	});
	const ONE_HOUR = 60 * 60;

	cookies().set("github_oauth_state", state, {
		path: "/",
		secure: false, //process.env.NODE_ENV === "production", -- can't be used until SSL certificate is provided by IT
		httpOnly: true,
		maxAge: ONE_HOUR,
		sameSite: "lax",
	});

	// Log zur Fehlersuche
	console.log(`GitHub OAuth redirect zu: ${url.toString()}`);
	console.log(`Verwendete Callback-URL: ${callbackUrl}`);

	return Response.redirect(url);
}
