import { GitHub } from "arctic";

// Bestimme die Callback-URL basierend auf der NEXT_PUBLIC_API_URL für das Backend
// und dem Standardport 3000 für das Frontend
const getCallbackUrl = () => {
  // Extrahiere die Basis-URL (Hostname) aus der Backend-URL, falls vorhanden
  let baseUrl = "http://localhost:3000";
  
  try {
    const apiUrlEnv = process.env.NEXT_PUBLIC_API_URL;
    
    if (apiUrlEnv) {
      // Wenn wir eine Backend-URL haben, extrahieren wir nur den Hostname-Teil für das Frontend
      const apiUrl = new URL(apiUrlEnv);
      const hostname = apiUrl.hostname;
      
      // Verwende den Hostname, aber mit Frontend-Port 3000
      baseUrl = `http://${hostname}:3000`;
    }
  } catch (error) {
    console.error("Fehler beim Parsen der API-URL:", error);
    // Fallback auf localhost
  }
  
  return `${baseUrl}/auth/login/callback`;
};

export const github = new GitHub(
  process.env.OAUTH_CLIENT_ID as string, 
  process.env.OAUTH_CLIENT_SECRET as string, 
  {
    enterpriseDomain: "https://git.i.mercedes-benz.com",
    redirectURI: getCallbackUrl(),
  }
);

export interface GitHubUserResult {
	id: number;
	login: string;
	name: string;
	email: string;
}
